from setuptools import setup,find_packages

setup(
    packages=find_packages(),
    name = "modified_pafy",
    author = "NA",
    description = "NA",
    install_requires = [],
    version = "1.0.0"
)